summaryrefslogtreecommitdiffstats
path: root/services/sensorservice/SensorService.cpp
diff options
context:
space:
mode:
authorSteve Block <steveblock@google.com>2012-01-06 19:20:56 +0000
committerMathias Agopian <mathias@google.com>2012-06-27 17:07:56 -0700
commitf5a1230d322c14c42331d0a1536b50c87742973b (patch)
tree23380badcd7472b9bf8e86b44d9ea81df6b882ea /services/sensorservice/SensorService.cpp
parent3c20fbed7f3a916ced10f2ed5a272271b7d81ede (diff)
downloadframeworks_native-f5a1230d322c14c42331d0a1536b50c87742973b.zip
frameworks_native-f5a1230d322c14c42331d0a1536b50c87742973b.tar.gz
frameworks_native-f5a1230d322c14c42331d0a1536b50c87742973b.tar.bz2
Rename (IF_)LOGE(_IF) to (IF_)ALOGE(_IF) DO NOT MERGE
See https://android-git.corp.google.com/g/#/c/157220 Bug: 5449033 Change-Id: Ic9c19d30693bd56755f55906127cd6bd7126096c
Diffstat (limited to 'services/sensorservice/SensorService.cpp')
-rw-r--r--services/sensorservice/SensorService.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/services/sensorservice/SensorService.cpp b/services/sensorservice/SensorService.cpp
index a1070d0..dd6c426 100644
--- a/services/sensorservice/SensorService.cpp
+++ b/services/sensorservice/SensorService.cpp
@@ -234,7 +234,7 @@ bool SensorService::threadLoop()
do {
count = device.poll(buffer, numEventMax);
if (count<0) {
- LOGE("sensor poll failed (%s)", strerror(-count));
+ ALOGE("sensor poll failed (%s)", strerror(-count));
break;
}
@@ -369,13 +369,13 @@ void SensorService::cleanupConnection(SensorEventConnection* c)
if (c->hasSensor(handle)) {
ALOGD_IF(DEBUG_CONNECTIONS, "%i: disabling handle=0x%08x", i, handle);
SensorInterface* sensor = mSensorMap.valueFor( handle );
- LOGE_IF(!sensor, "mSensorMap[handle=0x%08x] is null!", handle);
+ ALOGE_IF(!sensor, "mSensorMap[handle=0x%08x] is null!", handle);
if (sensor) {
sensor->activate(c, false);
}
}
SensorRecord* rec = mActiveSensors.valueAt(i);
- LOGE_IF(!rec, "mActiveSensors[%d] is null (handle=0x%08x)!", i, handle);
+ ALOGE_IF(!rec, "mActiveSensors[%d] is null (handle=0x%08x)!", i, handle);
ALOGD_IF(DEBUG_CONNECTIONS,
"removing connection %p for sensor[%d].handle=0x%08x",
c, i, handle);
@@ -598,7 +598,7 @@ status_t SensorService::SensorEventConnection::sendEvents(
return size;
}
//LOGE_IF(size<0, "dropping %d events on the floor (%s)",
// count, strerror(-size));
return size < 0 ? status_t(size) : status_t(NO_ERROR);
@@ -598,7 +598,7 @@ status_t SensorService::SensorEventConnection::sendEvents(
return size;
}
- //LOGE_IF(size<0, "dropping %d events on the floor (%s)",
+ //ALOGE_IF(size<0, "dropping %d events on the floor (%s)",
// count, strerror(-size));
return size < 0 ? status_t(size) : status_t(NO_ERROR);